# dopynion

Dominion in Python

## TODO

- faire une mini page web locale qui affiche le classement du moment
- gérer les exceptions dans les hooks et la désactivation des joueurs (y compris dans other_players)
- checker les identifiants de partie renvoyés par les API
- s'assurer que les stratégies random fonctionnent avec des parties en simultané
- afficher sur le site les dernières parties
- afficher les noms des équipes sur le leader board et le graphe
